==> 1.0.119+1.tar.gz: lib/components/UikRadioButtonList.dart <==
import "package:flutter/material.dart";
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikRadioButtonListProps.dart';

import '../utils/UikActionListner.dart';
import 'UikWidget.dart';

class UikRadioButtonList extends UikWidget {
  WidgetType _widgetType;
  UikRadioButtonListProps _uikRadioButtonListProps;
  UikRadioButtonList(this._widgetType, this._uikRadioButtonListProps)
      : super(_widgetType, _uikRadioButtonListProps);

  @override
  _UikRadioButtonListState createState() =>
      _UikRadioButtonListState(_uikRadioButtonListProps);
}

class _UikRadioButtonListState extends State<UikRadioButtonList> {
  final UikRadioButtonListProps _uikRadioButtonListProps;

  _UikRadioButtonListState(this._uikRadioButtonListProps);

  int selectedButtonIndex = -1;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: _uikRadioButtonListProps.height,
      padding: EdgeInsets.fromLTRB(
        _uikRadioButtonListProps.leftMargin,
        _uikRadioButtonListProps.topMargin,
        _uikRadioButtonListProps.rightMargin,
        _uikRadioButtonListProps.bottomMargin,
      ),
      child: ListView.builder(
        shrinkWrap: true,
        itemCount: _uikRadioButtonListProps.textList.length,
        itemBuilder: (context, index) {
          return GestureDetector(
            onTap: () async {
              setState(() {
                selectedButtonIndex = index;
              });

              print(_uikRadioButtonListProps.actionList[index].tap.type);

              await executeUikWidgetAction(
                  _uikRadioButtonListProps.actionList[index]);
            },
            child: Padding(
              padding: const EdgeInsets.only(bottom: 20.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      _uikRadioButtonListProps.textList[index],
                      // if (_uikRadioButtonListProps.subTextList!.isNotEmpty)
                      //   _uikRadioButtonListProps.subTextList![index],
                    ],
                  ),
                  Container(
                    height: 24.0,
                    width: 24.0,
                    decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      color: selectedButtonIndex == index
                          ? const Color(0xFFFEE440)
                          : Colors.white,
                      border: Border.all(
                        color: Colors.grey,
                      ),
                    ),
                    child: selectedButtonIndex == index
                        ? const Icon(
                            Icons.check,
                            color: Colors.black,
                          )
                        : null,
                  ),
                ],
              ),
            ),
          );
        },
      ),
    );
  }
}

==> 1.0.123+1.tar.gz: lib/components/UikRadioButtonList.dart <==
import "package:flutter/material.dart";
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikRadioButtonListProps.dart';

import '../utils/UikActionListner.dart';
import 'UikWidget.dart';

class UikRadioButtonList extends UikWidget {
  WidgetType _widgetType;
  UikRadioButtonListProps _uikRadioButtonListProps;
  UikRadioButtonList(this._widgetType, this._uikRadioButtonListProps)
      : super(_widgetType, _uikRadioButtonListProps);

  @override
  _UikRadioButtonListState createState() =>
      _UikRadioButtonListState(_uikRadioButtonListProps);
}

class _UikRadioButtonListState extends State<UikRadioButtonList> {
  final UikRadioButtonListProps _uikRadioButtonListProps;

  _UikRadioButtonListState(this._uikRadioButtonListProps);

  int selectedButtonIndex = -1;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: _uikRadioButtonListProps.height,
      padding: EdgeInsets.fromLTRB(
        _uikRadioButtonListProps.leftMargin,
        _uikRadioButtonListProps.topMargin,
        _uikRadioButtonListProps.rightMargin,
        _uikRadioButtonListProps.bottomMargin,
      ),
      child: ListView.builder(
        shrinkWrap: true,
        itemCount: _uikRadioButtonListProps.textList.length,
        itemBuilder: (context, index) {
          return GestureDetector(
            onTap: () async {
              setState(() {
                selectedButtonIndex = index;
              });

              print(_uikRadioButtonListProps.actionList[index].tap.type);

              await executeUikWidgetAction(
                  _uikRadioButtonListProps.actionList[index]);
            },
            child: Padding(
              padding: const EdgeInsets.only(bottom: 20.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      _uikRadioButtonListProps.textList[index],
                      if (_uikRadioButtonListProps.subTextList!.isNotEmpty)
                        _uikRadioButtonListProps.subTextList![index],
                    ],
                  ),
                  Container(
                    height: 24.0,
                    width: 24.0,
                    decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      color: selectedButtonIndex == index
                          ? Color(0xFFFFD60A)
                          : const Color.fromARGB(255, 227, 227, 227),
                    ),
                    child: selectedButtonIndex == index
                        ? const Icon(
                            Icons.check,
                            color: Colors.black,
                            size: 15,
                          )
                        : null,
                  ),
                ],
              ),
            ),
          );
        },
      ),
    );
  }
}
